==> haskell-hspec-api-2.11.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-api
version:              2.11.0
visibility:           public
id:                   hspec-api-2.11.0-1QV0nclgJ61yTm48sssj4
key:                  hspec-api-2.11.0-1QV0nclgJ61yTm48sssj4
license:              MIT
copyright:            (c) 2022-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
stability:            stable
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package provides a stable API that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  8698cf2728de02c74a84eb9365f64511
exposed:              True
exposed-modules:
    Test.Hspec.Api.Format.V1 Test.Hspec.Api.Format.V2
    Test.Hspec.Api.Formatters.V1 Test.Hspec.Api.Formatters.V2
    Test.Hspec.Api.Formatters.V3

hidden-modules:       Test.Hspec.Api.Format.V1.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-api
hs-libraries:         HShspec-api-2.11.0-1QV0nclgJ61yTm48sssj4
depends:
    base-4.17.2.1 hspec-core-2.11.0-3BrRykY5ZAxJNZLSrty7KG
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-api/html/hspec-api.haddock
haddock-html:         /usr/share/doc/haskell-hspec-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-api-2.11.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-api
version:              2.11.0
visibility:           public
id:                   hspec-api-2.11.0-EaBjvfejByC3j6BwWv63rW
key:                  hspec-api-2.11.0-EaBjvfejByC3j6BwWv63rW
license:              MIT
copyright:            (c) 2022-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
stability:            stable
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package provides a stable API that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  c0036a5c4a77e28334659a4b7434af23
exposed:              True
exposed-modules:
    Test.Hspec.Api.Format.V1 Test.Hspec.Api.Format.V2
    Test.Hspec.Api.Formatters.V1 Test.Hspec.Api.Formatters.V2
    Test.Hspec.Api.Formatters.V3

hidden-modules:       Test.Hspec.Api.Format.V1.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-api
hs-libraries:         HShspec-api-2.11.0-EaBjvfejByC3j6BwWv63rW
depends:
    base-4.17.2.1 hspec-core-2.11.0-AucdxD3wcaFF2bfFechfc2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-api/html/hspec-api.haddock
haddock-html:         /usr/share/doc/haskell-hspec-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
